@@ -9,7 +9,7 @@ from markdown.preprocessors import Preprocessor
 class KnowledgeMetaExtension(Extension):
     """ Meta-Data extension for Python-Markdown. """
 
-    def extendMarkdown(self, md, md_globals):
+    def extendMarkdown(self, md, md_globals=None):
         """ Add MetaPreprocessor to Markdown instance. """
         md.preprocessors.add("knowledge_meta",
                              KnowledgeMetaPreprocessor(md),
